#
# spec file for package pw3270
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) <2008> <Banco do Brasil S.A.>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#---[ Versions ]------------------------------------------------------------------------------------------------------

%define _product %(pkg-config --variable=product_name lib3270)

#---[ Packaging ]-----------------------------------------------------------------------------------------------------

Name:           pw3270
Version:        5.3
Release:        bp153.1.14
Summary:        IBM 3270 Terminal emulator for GTK
License:        GPL-2.0-only
Group:          System/X11/Terminals
URL:            https://github.com/PerryWerneck/pw3270

Source:         pw3270-%{version}.tar.xz
Patch0:         fix-appdata-xml.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Requires:       %{name}-branding = %{version}
Requires:       shared-mime-info

BuildRequires:  update-desktop-files

%glib2_gsettings_schema_requires

BuildRequires:  autoconf >= 2.61
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  binutils
BuildRequires:  coreutils
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  findutils
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  gettext-tools
BuildRequires:  m4
BuildRequires:  pkgconfig
BuildRequires:  sed
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libv3270) >= 5.3
%glib2_gsettings_schema_requires

%description
GTK-based IBM 3270 terminal emulator with many advanced features. It can be used to communicate with any IBM host that supports 3270-style connections over TELNET.

Based on the original x3270 code, pw3270 was originally created for Banco do Brasil, and is now used worldwide.

#--[ Configuration & Branding ]---------------------------------------------------------------------------------------

%package branding
Summary:        Default branding for %{name}
Group:          System/X11/Terminals

Requires:       %{name} = %{version}
BuildArch:      noarch

Requires(post):		desktop-file-utils
Requires(postun):	desktop-file-utils

%description branding
GTK-based IBM 3270 terminal emulator with many advanced features. It can be used to communicate with any IBM host that supports 3270-style connections over TELNET.

This package contains the default branding for %{name}.

%package keypads
Summary:        Keypads for %{name}
Group:          System/X11/Terminals
Requires:       %{name} = %{version}
BuildArch:      noarch

Conflicts:      otherproviders(pw3270-keypads)
Enhances:       %{name}

%description keypads
GTK-based IBM 3270 terminal emulator with many advanced features. It can be used to communicate with any IBM host that supports 3270-style connections over TELNET.

This package contains the keypads for %{name}.

#---[ Build & Install ]-----------------------------------------------------------------------------------------------

%prep
%setup
%patch0 -p1

%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
NOCONFIGURE=1 ./autogen.sh

%configure --with-release=%{release} CFLAGS="${CFLAGS} -fpie" LDFLAGS="${LDFLAGS} -pie"

%build
make %{?_smp_mflags} clean

# parallel build is broken
make all -j1

%install
%make_install

%find_lang pw3270 langfiles

%fdupes %{buildroot}/%{_prefix}

%files -f langfiles
%defattr(-,root,root)
%license LICENSE
%doc AUTHORS README.md

# Main application
%dir %{_datadir}/%{_product}
%dir %{_datadir}/%{_product}/ui
%dir %{_datadir}/%{_product}/keypad
%dir %{_libdir}/%{_product}-plugins
%dir %{_datadir}/%{_product}/icons

%{_bindir}/%{_product}

# Configuration & Themes
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/%{_product}/icons/gtk-*.svg
%{_datadir}/%{_product}/icons/connect-*.svg
%{_datadir}/%{_product}/icons/disconnect-*.svg

%{_datadir}/applications/*.desktop
%{_datadir}/appdata/*.appdata.xml
%{_datadir}/icons/hicolor/scalable/apps/*.svg

%{_datadir}/mime/packages/*.xml

%files branding
%defattr(-,root,root)

%{_datadir}/%{_product}/ui/*
%{_datadir}/%{_product}/*.svg
%{_datadir}/%{_product}/icons/%{_product}.svg

%files keypads
%{_datadir}/%{_product}/keypad/*

%posttrans
/usr/bin/update-desktop-database

%postun
/usr/bin/update-desktop-database

%changelog
* Tue Nov 24 2020 Perry Werneck <perry.werneck@gmail.com>
- Adding fix-appdata-xml.patch to fix problems with gnome-software.
* Mon Nov  2 2020 perry.werneck@gmail.com
- Update to version 5.3+git20201102:
  * Fixing package build.
  * Removing .png files, using only the svg ones.
  * Adjusting header bar defaults.
  * Adjustments for openSUSE 15.2.
  * Update README.md
  * Use 'gnome' style as default on linux and classic in other OSs.
  * Disabling F10 redirection.
  * Adjusting default action lists.
  * Enabling set/reset of kpalternative in the modern interface.
  * Moving generic tools to libv3270.
  * Auto updating toolbar when icon style changes.
  * Implementing standard models for menus & comboboxes.
  * Adding copy-image menu option.
  * Adding "copy-as-html" action.
  * Adding 'view trace' option on the popup menus.
  * Pre-defining session file name on save dialogs.
  * Creating session file when a desktop icon is built with default session.
  * Adding method to suggest session filename and path.
  * Processing toolbar-position settings.
  * Adding tooltips in the header bar buttons.
  * Moving application icons to the 'icons' folder.
  * Adding support for customized icons.
  * Adding option for symbolic icons in the header bar.
  * Implementing use of symbolic icons in toolbar.
  * Updating appdata.
  * Scanning standard directories for session definition files.
  * Adding appdata.xml
  * Adding architecture in about window. Usefull for windows users.
  * Project URL changes by locale.
  * Loading/saving dialog responses from session file.
  * Renaming default filename.
  * Adding custom mime-type for pw3270 session settings file
  * Using PIE instead of pic.
  * Refactoring keypads.
  * Adding deb post install/uninstall scripts.
  * removed patch: optional_optipng.patch
* Mon Jun  8 2020 Perry Werneck <perry.werneck@gmail.com>
- Optipng is not in the SLE-15 default repositories
- added patch: optional_optipng.patch
* Thu Jun  4 2020 perry.werneck@gmail.com
- Update to version 5.3:
  * Adding method to set environment variables from session settings file (allow use of an alternative openssl config file).
  * Adding fallbacks for application menu.
  * PACKAGE_RELEASE macros is now a string to allow use of rpm's release.
  * Adding option to switch the user interface.
  * Add build instructions for macOS
  * Redirecting gtk logs to lib3270.
  * Using the new dialog section element who adapts to windows UI.
  * Refactoring session rename method.
  * Fixing application preferences dialog warning.
  * The defaults for windows and linux aren't the same.
  * Adding clipboard settings dialog.
  * Updating properties.
  * Cleaning up.
  * Adding toolbar properties menu.
  * Refactoring "open" actions.
  * Refactoring "window" actions.
  * Refactoring application settings dialog & related widgets as gobjects.
  * Terminal actions now lives in libv3270.
  * Conditional and property actions moved to libv3270.
  * Moving dialog action to libv3270.
  * Refactoring plugin engine.
  * Adding popup menu over OIA.
  * Only customized sessions can be renamed.
  * Implementing session name change dialog.
  * Implementing tab-menu.
  * Implementing popup menu on tab labels.
  * Refactoring the open session/url from command line.
  * Refactoring terminal support methods.
  * Implementing "open session in the window" action.
  * Implementing the new "save session" dialog.
  * Adding toolbar settings dialog.
  * Fixing portability issue detected by OBS.
  * PF & PA key and lib3270's actions are now on libv3270.
  * Implementing toolbar actions edit dialog.
  * Implementing action viewer widget.
  * Implementing application settings.
  * Loading/saving print settings to/from session file.
  * Adding accelerator settings tab on the session properties dialog.
  * Use convert -strip
  * ui-style is now defined by gsettings.
  * Updating to latest versions of v3270 & lib3270.
  * Adding missing license info.
  * Getting appname from lib3270.
  * Removing use of deprecated function "get_hostname".
  * Adding support for oversize.
  * Using the new standard error popup for print errors.
  * Linux custom print widget is now managed by libv3270.
  * Replacing save dialog with the new version from v3270.
  * linux log is now sent do system log.
  * Updating package to follow naming guidelines.
* Wed Mar 25 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to make package build reproducible (boo#1047218)
* Thu Feb 20 2020 Max Lin <mlin@suse.com>
- Leap 15.2 and SLE15 SP2 has newer librsvg, extend the conditional
  for "BuildRequires: rsvg-convert"
* Wed Oct 23 2019 ro@suse.de
- fix build-requires for factory/tumbleweed
  rsvg-convert tool is now in rsvg-convert package
* Fri May 31 2019 perry.werneck@gmail.com
  * Doing a "clean exit" on SIGTERM.
  * Updating translation.
  * Updating translation.
  * Fixing save message.
  * Fixing the application name with ./configure option.
  * Showing message on configuration update.
  * Updating rpm packaging.
  * Fixing icon and application name.
  * Adding desktop file.
  * Creating application icon in standard folder.
  * Emitting message when the logo is not available on about window.
  * Fixing memory allocation error on about dialog.
  * Fixing bug in about window detected on windows version.
  * Fixing win32 runtime.
  * Updating read me.
  * Updating versions in win packate.
  * Fixing file version indication in win32 package.
  * Fixing windows build.
  * Removing windows native dialog.
  * Fixing windows build.
  * Removing unused sources.
  * Adding compiled version of the schemas in the runtime package.
  * Adding gtkfilechooser schema to runtime package.
  * Comentando fontes do código que foi transferido para a libv3270.
  * Adding script to build and install lib3270 and libv3270 on msys2
  * Fixing msys2 build.
  * Disabling unused code.
  * Updating translations.
  * Renaming application transfer file dialog to avoid conflicts.
  * Updating package control file.
* Tue Feb 26 2019 perry.werneck@gmail.com
- Update to version 5.2:
  * Updating linux packages.
  * Removing libv3270 submodule
  * Updating branding Makefile.
  * Updating autogen
  * Updating project.
  * Fixing RHEL 7 builds.
  * Removing unused UI files.
  * Fixing .deb builds
  * Fixing RHEL7 build.
  * Updating linux package.
* Thu Sep 14 2017 jengelh@inai.de
- Put libpw3270 into its own package (shared library guideline).
- Drop require on /usr/bin/openssl, this is unusual for a library
  to request.
- %%configure already sets CFLAGS,CXXFLAGS, do not set it again.
  Replace old RPM variables. Remove redundant %%clean section.
  Do not run fdupes across hardlink boundaries.
- Fix one RPM category. Trim redundant words from description.
* Wed Sep 13 2017 erico.mendonca@suse.com
- fix_actions.patch: patch is no longer necessary.
- keypad_update.patch: patch is no longer necessary.
- mutex_include.patch: patch is no longer necessary.
- gtk2-fixes.patch: patch is no longer necessary.
- file_chooser.patch: patch is no longer necessary.
- fix_oorexx_charset.patch: patch is no longer necessary.
* Wed Sep 13 2017 perry.werneck@gmail.com
- Updating to the latest git level, closing package for distribution.
- Java, Rexx, PHP, Mono and other extensions for scripting are now separated packages.
* Thu Jan 26 2017 perry.werneck@gmail.com
- Fixing .deb builds.
* Thu Jan 19 2017 perry.werneck@gmail.com
- Removing unused sources, refactoring Makefiles, build & installation
* Tue Dec 27 2016 perry.werneck@gmail.com
- Updating deb dependencies.
* Fri Nov  4 2016 perry.werneck@gmail.com
- Fixing PHP5 requires.
* Fri Oct 21 2016 perry.werneck@gmail.com
- Fixing script file chooser
- added patches:    fix_oorexx_charset.patch
    mutex_include.patch
    keypad_update.patch
    file_chooser.patch
    fix_actions.patch
    gtk2-fixes.patch
* Fri Oct 21 2016 perry.werneck@gmail.com
- Fixing charset problem on ooRexx plugin
* Fri Oct 21 2016 perry.werneck@gmail.com
- Fixing backport for bug 998842 (https://bugzilla.suse.com/show_bug.cgi?id=998842)
    on OpenSUSE 13.2
* Thu Oct 20 2016 perry.werneck@gmail.com
- Adding PHP5 support on Debian builds
* Wed Oct 19 2016 perry.werneck@gmail.com
- Fixing gtk2 builds.
